@@ -1,5 +1,5 @@
 import pypandoc
 
-z = pypandoc.convert("README.md", "rst", format="markdown")
+z = pypandoc.convert_file("README.md", "rst", format="markdown")
 with open("README.rst", "w") as outfile:
     outfile.write(z)
