@@ -11,3 +11,5 @@ from .newport_xps_rl import AsyncNewportXpsRL
 from .tdk_lambda import AsyncTdkLambda
 from .julabo import AsyncJulabo
 from .tti_cpx400dp import AsyncTtiCpx400dp
+from .lauda import AsyncLauda
+from .arduino_gbf import AsyncArduino
